ogt-py = Open GeoTechnical in python
=========================================

- Docs at https://open-geotechnical.gitlab.io/ogt-py/

Install
===========================

- see https://open-geotechnical.gitlab.io/ogt-py/install.html



